Afrikaans
Akan
Albanian
Amharic
Arabic
Armenian
Azerbaijani
Basque
Belarusian
Bemba
Bengali
Bihari
Bosnian
Breton
Bulgarian
Cambodian
Catalan
Cebuano
Cherokee
Chichewa
Chinese (Simplified)
Chinese (Traditional)
Corsican
Croatian
Czech
Danish
Dutch
Esperanto
Estonian
Ewe
Faroese
Filipino
Finnish
French
Frisian
Ga
Galician
Georgian
German
Greek
Guarani
Gujarati
Haitian Creole
Hausa
Hawaiian
Hebrew
Hindi
Hmong
Hungarian
Icelandic
Igbo
Indonesian
Interlingua
Irish
Italian
Japanese
Javanese
Kannada
Kazakh
Kinyarwanda
Kirundi
Kongo
Korean
Krio (Sierra Leone)
Kurdish
Kurdish (Soranî)
Kyrgyz
Laothian
Latin
Latvian
Lingala
Lithuanian
Lozi
Luganda
Luo
Luxembourgish
Macedonian
Malagasy
Malay
Malayalam
Maltese
Maori
Marathi
Mauritian Creole
Moldavian
Mongolian
Myanmar (Burmese)
Montenegrin
Nepali
Nigerian Pidgin
Northern Sotho
Norwegian
Norwegian (Nynorsk)
Occitan
Oriya
Oromo
Pashto
Persian
Polish
Portuguese (Brazil)
Portuguese (Portugal)
Punjabi
Quechua
Romanian
Romansh
Runyakitara
Russian
Samoan
Scots Gaelic
Serbian
Serbo-Croatian
Sesotho
Setswana
Seychellois Creole
Shona
Sindhi
Sinhalese
Slovak
Slovenian
Somali
Spanish (Latin American)
Sundanese
Swahili
Swedish
Tajik
Tamil
Tatar
Telugu
Tigrinya
Tonga
Tshiluba
Tumbuka
Turkish
Turkmen
Twi
Uighur
Ukrainian
Urdu
Uzbek
Vietnamese
Welsh
Wolof
Xhosa
Yiddish
Yoruba
Zulu
[ Suspenseful music plays ]
♪♪
Woman: [ Screaming ]
♪♪
[ Train whistle blowing ]
♪♪
The next carriage, sir.
♪♪
Noah: Alright, alright. Okay, come on.
Clear the way please, clear. Thank you.
Who can tell me what happened?
We all came in here for lunch. We went into a tunnel.
When we came out the other side...
there he was.
Can I ask you all to wait in the next carriage, please?
Do as the Inspector asks.
♪♪
Excellent job, by the way.
Thank you.
[ "Just as the Tide Was Flowing" plays ]
♪♪
♪ One morning in the month of June ♪
♪ Down by a rolling river ♪
♪ There a weary traveller chanced to stray ♪
♪ And he beheld his lover ♪
♪ Her cheeks were red, her eyes were brown ♪
♪ Her hair in ringlets hanging down ♪
♪ She'd a lovely face without a frown ♪
♪ Just as the tide was flowing ♪
♪♪
♪♪
[ Seagulls squawking ]
♪♪
Margo: Alright, everyone,
you can get on with the rest of your Saturday,
but we've got a full dress rehearsal tomorrow,
so don't be late.
You alright for any costume nips and tucks tomorrow?
I'll bring my box.
Thank you so much for doing this.
Sorry it was all a bit last-minute.
No, you're very welcome.
It made for an interesting weekend.
-[ Chuckles ] -Any news on Terry and Lynne?
Well, the embassy's arranged for a new passport
and there's a flight the day after tomorrow,
so they should make the actual night.
But if you can stand in again for tomorrow's dress rehearsal
that will really help. -I'm free.
Well, I'll have to check my crowded social calendar,
but I'll do my best.
-You're a star. -[ Chuckles ] Hear that?
The director called me a star.
♪♪
And here they are, our famous Inspector O'Keefe
and Lady Wickham.
Ha-ha-ha!
You did a wonderful job, you know.
-Didn't they, Katie? -Kate.
Your line -- "“Do as the Inspector asks"” --
perhaps a tad more urgency? -George: Here we go.
I'm just trying to get it right, George.
Esther's only standing in, Katie.
Even so. And my name is Kate.
I'll try harder, Kate.
Anyone fancy a quick one?
As the new boy, I feel I should buy you all a drink.
Well, if you're paying.
-Excuse me. -Not me, thanks.
I've got a hungry teenager waiting to be fed.
I want to go over my lines again.
Home for me, too, but have fun.
Looks like a cheap night, then.
See you all tomorrow. Don't be late!
Toot-toot! Ha-ha!
Is it too late to change the murder victim?
She is a bit full of herself. Had an audition for Emmerdale.
Now she thinks she's Judi Dench.
Huh! Ooh, is he part of the play?
He's rather pretty for an engine driver.
No, I don't think so.
Well, maybe he's Lady Wickham's secret lover.
More to the point,
do you think he'd let me take a look at the engine?
No harm in asking. Or I could do it for you.
No, it's okay. I can manage.
-Are you the driver? -Not exactly.
I'm the fireman, Kieran.
Kieran Fish. I look after the boiler.
Harry there is the driver.
Ah. I was hoping to take a look around.
-Go on. Jump on. -Can I?
♪♪
This is amazing!
My granddad used to drive these back in the day.
I've loved them ever since.
All the gauges on the left there, that's my stuff,
keeping the boiler at temperature for when we set off.
Harry works the throttle and the brakes.
It's very much a two-man operation?
Doesn't work otherwise.
May -- May I?
Knock yourself out.
♪♪
[ Train whistle blows ]
♪♪
♪♪
Oh! Oh!
Help! Help!
♪ Again, again, again ♪
♪ Again, again, again ♪
[ Train whistle blowing ]
Harry: Get off my train!
[ Stifled laughter ]
Sounded like you were having fun.
The driver seemed a bit cross.
But yes, something else ticked off the bucket list.
♪♪
♪♪
I know we're related, but you're table blocking.
Hmm? Martha: You've been here
for three hours and you haven't actually bought anything.
-I'm shopping, dear. -Martha: For what?
-A man. -Excuse me?
Elsie Relish at the farm shop told me about this new app.
It's called Silver Heart,
for people of a certain age looking for companionship.
It's rather like window shopping.
If you don't like the look of them, you double tap
and they go in the bin, but if you do, you swipe up
and they go in your shopping basket.
You're not actually buying them?
Heavens, no. It's a metaphorical shopping basket.
-At least I hope it is. -[ Cellphone chimes ]
Martha: Just for companionship?
Well, Elsie uses hers for casual sex,
but I'd just like someone to help me walk the dog.
You haven't got a dog.
Well, no, but I put one on my profile.
I thought it made me sound... warmer.
[ Chuckles ] I called him Humphrey.
So you're using an imaginary dog
named after my fiancé to lure men back to the cottage?
-Yes, dear. -Hello.
Ah! How was it?
Margo said I was very convincing.
Playing the part of a detective.
-Ah, yes, I see what you mean. -[ Chuckles ]
-I'm sure you were amazing. -Anne: Ooh!
-Are you okay, Anne? -Hmm?
Martha: She's shopping.
Anne: Oh, no, he's got a lazy eye.
I'd never know if he's paying attention.
♪♪
♪♪
It's hard to think of your mum as someone's girlfriend.
Bit like trying to imagine Donald Trump ice skating.
-Does it bother you? -Martha: A bit.
I mean, it's three years since we lost Dad,
so I shouldn't be surprised, I suppose.
But you are?
I just need to get my head around it.
Hmm.
I think I'm more worried that she's doing it online.
What if she's catfished?
-Er...? -Meet someone
pretending to be someone they're not.
Well, I could talk to her if you like, um,
explain the perils of online dating
from a police perspective?
Good idea. Might make her more careful.
Humphrey: Consider it done.
I think there must be something in the air --
your mum looking for love, you and I doing date nights.
Well, we Lloyds are very romantic,
I'll have you know. -Indeed you are.
Though I'm not sure how many date nights
we'll get if we're allowed to foster.
Next steps are interviews and home visit.
She thinks everything is on track.
Good.
I must confess, I am really excited now it's happening,
although I am a little bit, um...
[ Inhales, exhales deeply ]
Me, too.
Though if it cuts down on our date nights,
we'd better make the most of this one.
Absolutely.
[ Glasses clink ]
♪♪
[ Train whistle blows ]
♪♪
See how you get on tonight.
I can always let it out a bit more.
-Ow! -Vivienne: Oh, sorry.
Alright, everyone, final dress rehearsal.
Next time we do it will be in front of paying guests,
so let's not leave anything in the locker.
[ Train whistle blows ]
♪♪
Alright?
♪♪
To be clear, the deceased was seen alive
and well at the very moment the train entered the tunnel,
and yet by the time it re-emerged from the tunnel...
he was dead.
♪♪
♪♪
Examine the line, mate. Had a call about debris.
Okay, mate.
Never worry, everyone, this is Dean Prior,
the last tunnel before Shipton Abbott.
♪♪
♪♪
Margo: Hold your positions.
♪♪
♪♪
♪♪
And would you say you were close?
Esther: This heat is interminable.
I need a glass of water.
Humphrey: It's clear that everyone in this carriage
was also in the buffet car at the very moment
the train entered the first tunnel.
So, it is equally clear that the murderer
is someone sat in front of me now.
-Sir? -Hmm?
I think you need to come and see this.
That's not your line.
-[ Whispers ] He's dead. -No, that's not it either.
-Margo, keep everyone in here. -Cut!
Er, Esther...
♪♪
He's really dead.
I know. The last tunnel.
Someone must have sneaked back in here.
Which means one of those people in there...
really is the murderer.
♪♪
[ Train whistle blows ]
[ Sirens wailing ]
[ Train brakes screeching ]
♪♪
♪♪
I want everyone off the platform.
Policeman: Back, please. Move back.
-Back. No. -[ Indistinct chatter ]
I've let all the players go, but made it clear
we'll need to talk to them again.
Good, thank you.
Kelby: Platform's clear, sir.
-Just the press outside. -Okay, thanks.
-Have we searched the train? -Yes, sir.
Only three carriages were open --
the one used as the backstage area,
the buffet car, and the passenger carriage
used for the performance.
-The other one was locked. -What about train staff?
Kelby: There was an engine driver and a fireman.
I talked to them both, but they didn't see
or hear anything unusual
and were together in the engine cab the whole time.
Which means our killer has to be one of
the Shipton Abbott Players.
My thoughts exactly, sir.
Well, hopefully we can rule out three of those.
Humphrey: Can we?
-You, me, and Margo, sir. -Right. Good point, Sergeant.
If we rule out you, me, and Margo,
that leaves us with four suspects,
and any one of them could have sneaked back in here
when the train went through the last tunnel.
Hmm. Do you know how hard it is to stab someone in the back?
I've never tried it, but not easy, I bet.
No, it is not.
The muscles in the upper part of the back
are much thicker than most people imagine.
It takes a great deal of force to penetrate them.
Our victim was a big man, yet there's no sign
of any kind of a struggle,
which suggests that he was standing with his back
to whoever stabbed him. -At the buffet table.
But if that's the case...
...then aren't we missing something?
There's no blood.
♪♪
I got these from the Shipton Players website.
Margo: I went to school with him.
Used to pick his nose and put it in his inkwell.
[ Chuckles ]
What's an inkwell?
It's a little pot you put your ink in.
For your pen.
-[ Telephone rings ] -Like a quill.
Do you want a smack in the mouth, hmm?
Shipton Abbott Police Station.
Can one of you two phone the Chief Superintendent?
Why? Margo: Press are having a field day.
It's escalated from local papers to the nationals.
I mean, an actual murder
on a murder mystery night is bad enough,
but it happening under the noses of two serving police officers
has got them all whipped up into a frenzy.
Mm, that's one for you, Sergeant.
I'll call her.
[ Telephone beeps ]
-[ Clears throat ] -Margo.
-Margo: Mm? -The Shipton Abbott Players --
tell me about them. -Right.
Kate Potts, wannabe actress, fresh out of drama school,
likes the sound of her own voice,
but harmless enough.
Polly Deakins just reported a peeping Tom.
She's got a nerve --
all the curtain twitching she does.
Even so, better go check it out.
Yeah.
George Harris, widower,
lost his wife Louise about six years ago,
so joined every group and activity in Shipton Abbott.
Moans at all of them.
Vivienne Bishfield, she's a biology teacher at the college.
I think she moved here from Exeter
about five or six years ago.
Heart of gold.
Noah Culpepper, bit of a geek, but harmless.
Divorced. His wife Janet ran off with his best mate. Sally.
And were they all friends with Paul Yellen, our victim?
No, that's the thing, see. None of us were.
He only just joined us a few days earlier.
I think he just bought a house here.
So he's not local?
No, I'm pretty sure he said he was from Hastings.
I mean, that's why he was our victim.
It's the tradition.
The newest member always gets to play the murder victim.
Yes, unfortunately, in this case, quite literally.
♪♪
♪♪
And when was this exactly, Polly?
Last night, after dark.
10:00, maybe? How's your mother?
Oh, she's good, thanks.
She still cleaning up at the school?
Er, not anymore, no. She got a job at the card shop.
And you say this man was standing across the road?
Across the road, but looking this way.
She still with that waste of space with the motorbike?
You mean my dad? Yep, she's still with him.
Um, but he hasn't got a bike anymore.
He's got a Hyundai.
Oh. Never liked him. He was a foot-tapper.
Never trust a man who taps his foot when you're talking to him.
Right, so, he was across the road but looking at you.
I didn't say he was looking at me.
I said he was looking over this way,
but he was up to no good, you could tell.
How long would you say he was there?
Oh, over an hour.
He only left '‘cause some woman caught him nosing about.
Gave him a right telling off.
-Which woman? -No idea.
Like I said, it was dark.
Could you describe either of them?
He was medium height, had a woolly hat on.
She were medium height, no hat.
Humphrey: There's not much more we can achieve
'til the labs open in the morning,
but, um, let's talk to Hastings police,
see what they can tell us about the victim.
-Right. -So, have you got
anything exciting planned for this evening?
Ooh, beans on toast, bath, then help Zoe with her CV.
-Is she looking for a job? -Yeah.
Well, I'm doing most of the looking, if I'm honest.
She's a good kid, but like every other 16-year-old,
she's just on her phone all day.
Honestly, I want her to get out and meet people.
Yes, the curse of the worldwide web.
I've got a similar problem with Martha's mum.
-She's looking for love online. -Hmm!
-I think the plan tonight... -[ Brakes screech ]
...is to talk her out of it.
You're not talking me out of it.
Even after all the things Humphrey has just told you?
-Anne: He made them up. -He didn't.
A woman who just happened to be my age
living in Devon agrees to meet a stranger in a pub,
only to discover an axe hidden under his coat,
which she sees poking out when he goes to the bathroom?
-Too much? -Too much.
Besides which, I've already got a match.
-What? -His name's Oliver. He's 63.
He has his own hair, teeth, and house,
and we're having dinner tomorrow evening.
-Tomorrow? -Anne: He's coming here.
-What? -He wants to sample my tagine.
-[ Stifled laugh ] -I bet he does.
And what if he wants to meet Humphrey?
Why would he want to meet Humphrey?
-Your imaginary dog. -You have an imaginary dog?
I'll say he's at the vet's.
I know you're worried about me, Motty,
and that's very sweet, but you can't expect me
to be on my own for the time I've got left.
Well, you've got us.
You've got your own lives to live.
-What if you move away? -We won't.
You might. And then what would I do?
Leave here and move in with you?
No.
I -- I mean we'd love you to, er, if we did.
Go, I mean, somewhere. But we're not. But if we did...
So -- So when I say no, I actually mean y-- yes,
if we did, but we're not.
Which is why I -- We just want you to be happy.
[ Chuckles ] Good.
Because having Oliver here for dinner tomorrow evening
will make me very happy indeed.
[ Dishes clatter ]
Martha: I suppose I shouldn't worry.
After all, I didn't know what she got up to
when we were in London. -Humphrey: Well, exactly,
and I'm sure Oliver is a thoroughly decent chap.
Yes. And if he's not,
we can murder him and dump his body in the river.
Yes, agreed.
♪♪
Man: Morning.
♪♪
I've got nothing to say, and the Detective isn't here,
so you're wasting your time. -Reporter: Can you give us
any more information, Margo? Anything at all?
[ Indistinct chatter ]
Oh, and there's no T in Margo.
Esther: Okay, so we're waiting
for the full post-mortem and toxicology reports,
but the preliminary autopsy came through first thing.
It confirms the blade puncture in the right lung
as probable cause of death.
There's no other injuries of note,
so no visible signs of a struggle.
Er...
Er... [ Clears throat ] Harry Bishfield?
Hello. We met briefly the day before yesterday.
Yes, I -- I was, er, with the [Whistles] and the...
Mm, yeah, yeah, I remember.
Heh-heh. Yes, right. Um, sorry.
Am I right in thinking the train didn't stop at all
during the dress rehearsal yesterday?
We had a call to slow down through one of the tunnels,
didn't we, boss? -Yeah.
-There was a report of debris. -When you say slow down,
enough time for someone to jump on the train and off again?
Maybe.
Did either of you see anyone on or near the track
during the journey yesterday? -Kieran: Not me.
[ Train whistles blowing in distance ]
[ Indistinct chatter ]
-[ Clears throat ] Sir? -Hmm?
Okay.
Thanks, gents.
Just the Super. [ Chuckles ]
Um, can I just say, er, you look very...
good.
Er, I mean, smart.
Er, everything is, um... pressed, er, nicely.
I'm just gonna...
[ Scoffs ]
Kelby: Sir.
-Ma'am. -I hear you've decided
not to run your murder room from regional HQ.
Well, it's early days yet, ma'am.
-We're still gathering evidence. -Chief: I'm not sure
what the murder rates are at the Met these days,
Inspector, or the Caribbean for that matter,
but thankfully here, it's rare enough for us
to take a murder inquiry very seriously.
As do I.
-Can I be frank? -Of course.
Chief: This whole thing has caused quite a stir.
And because of the media interest,
the powers that be are particularly keen
for an early resolution.
I understand, ma'am.
I hope you do, Inspector, I really do,
because all eyes are on you.
And given your station house is under review,
there may be more riding on this case than you know.
♪♪
♪♪
I read somewhere that whatever you wear on your first date
reflects your personality.
I thought you said it wasn't a date.
Anne: Well, it isn't. It's an introductory meeting,
but I think the same rules apply.
What about my camel trouser suit?
-Martha: Isn't that a bit formal?
-Oh, maybe.
Martha: Look, you're cooking a meal.
You just need something casual,
something you feel comfortable in.
Anne: I don't want to look like a frump, do I?
He won't think you're frumpy.
Look, Mum, I've got to go. Just be yourself.
-Love you, Motty. -Martha: You, too. Bye.
Bye.
-Humphrey: Peter? -Noah: Noah.
Peter is the name of the train conductor what I was playing.
I plays him Scottish.
-Toot-toot! -Heh.
Yesterday at the dress rehearsal,
did you notice anything unusual?
No. Got to the train,
Viv did her final costume fitting.
Oh, um...
Vivienne Bishfield. She played Gill Bond.
Right. Um, and then what?
But you was there.
Well, tell me anyway.
We moved to the buffet car,
George helped Paul put the fake knife in place.
Paul laid down, Margo shouted, "“Action"”, Katie screamed.
Then I was sent by Lady Wickham --
Sergeant Williams --
to fetch Inspector O'Keefe -- you.
Yeah.
At any point after the interview scene,
did you go back into the buffet car?
No. Why would I?
Humphrey: And on the day of the dress rehearsal,
did Paul Yellen seem different to you than the day before?
I didn't really talk to him.
I mean, I try to help everyone, you know,
with a bit of direction here and there,
but I had no call to do so with him.
He's just the body.
Quite.
I saw him talking to George, though.
Did you hear what they were talking about?
Argyle. Turns out we were both supporters.
If you're not buying that, it belongs on the shelf.
I'd met him a few days ago in Kitty Jay's.
He said he was new to the area,
so I suggested he come to Players, get to know people.
Told him he didn't have to worry about lines or anything,
because as the new boy, he'd just be a dead body.
Turns out I was right.
That's odd, don't you think?
The most miserable man in the world working in a toy shop?
No, Paul Yellen supporting Plymouth Argyle
when he lived in Hastings.
Who's next?
Um, Vivienne Bishfield.
Ah.
♪♪
Humphrey: So you arranged all the costumes?
Well, the Players have their own stock of costumes,
but they're all a bit old, so I just do running repairs.
My mum's a seamstress. [ Chuckles ]
Something to remember about amateur dramatics --
never let on you have a particular skill. [ Chuckles ]
Your husband Harry is the train driver?
A case in point.
At drinks one evening, he happened to mention
that he drove a steam train.
Well, Margo was on him like a shot.
Yes, right.
So there was nothing about Paul Yellen
at the dress rehearsal that struck you
as being unusual in any way?
Er, no, but, er,
I didn't really know him well enough to notice
even if there was.
Right.
Not one of the neighbours saw or heard this mystery bloke,
or the woman that chased him off.
He's probably just a figment of Polly Deakins' imagination.
-Humphrey: Margo? -Mmm?
What have we got on the deceased?
If he lived in Hastings
he must have been living in a cave somewhere.
He's not on the voting register, council records, HMRC,
or any other official list.
I mean, there's nothing on the PNC either,
nor social media.
I'm going back to see Polly.
Didn't you say he'd just bought a house in Shipton Abbott?
Maybe talk to the solicitors who did the conveyancing.
Righty-o.
Humphrey: Oh, and the engine driver
said something about debris on the line
which made the train slow down.
Maybe check out what that was. It might be significant.
The problem is, the why can sometimes lead you
to finding a who and then eventually how,
or a how can sometimes point you to a who and then a why.
But we haven't got a why.
I'm not even sure if we've got a how.
The autopsy said the knife pierced a lung.
But where was the blood around the body?
What are we missing?
Everything, by the sound of it.
We've had the press outside all morning.
HQ think we might need to do a press conference.
A public appeal might be an option
if we can't find out more about Paul Yellen.
True. Did we check his home?
Yeah, we sent a team there. The house was empty.
They got in and did a quick search.
Nothing of note found.
Then maybe we should take another look.
Come along, Sergeant.
Esther: Couple of letters,
a log book, and a new credit card.
Nothing upstairs, but it's clear only one bedroom is being used.
Yes, down here is pretty much the same.
Ready meals for one.
One mug, one plate.
Everything is pretty basic.
No family photos,
nothing personal at all as far as I can see.
Seems he had a very lonely life.
[ Seagulls squawking ]
♪♪
♪ How'd you like the sound of those four letter words? ♪
♪ They make me look so clever as I fall to the earth ♪
♪ I wanna walk through the morning ♪
♪ And I've not seen the night ♪
♪ I wanna hold on to you, darlin' ♪
♪ And make you feel alright ♪
♪ Darlin', won't you come and stay with me? ♪
Here's my mobile number. If he turns up again, call me.
♪ Ah ♪
Humphrey: Are you thinking what I'm thinking?
Kelby: Not sure. What are you thinking?
That whoever was watching from across the street
wasn't watching Polly.
He was watching Paul Yellen.
I was just about to say that.
Margo: Okay.
So I spoke to the solicitor who dealt with the house.
Paul Yellen didn't buy it.
He inherited it from the previous owner,
a Mrs. Sarah Scarcroft,
who left everything to Yellen in her will.
Find out what Paul Yellen was to her, please, Margo.
Kelby, what do we know about the man who was watching the house?
Er, sir, er, medium height, er, wearing a woolly hat.
It's not much. What about the woman he was seen with?
Same, without the hat.
[ Telephone rings ]
Margo: Shipton Abbott Police Station.
Just a second.
Chief Superintendent Woods.
♪♪
♪♪
Ma'am?
♪♪
Good evening, Selwyn.
[ Selwyn quacks ]
Saved you a treat.
Stole it from Margo's desk.
-Martha: Psst! -Selwyn?
Over here.
Oh.
Hello. Oh!
♪♪
What are we doing?
-He's in there. -Who is?
Martha: Oliver. I saw a man in the window.
She must have sneaked him in.
Humphrey: Why would she sneak him in
when she's already told us he's coming?
Well, she didn't introduce me. That's as good as sneaking.
Oh, you stay here. I'm going over.
To do what?
To do what?
♪♪
♪♪
Hello.
Can I borrow a cup of sugar?
♪♪
And some bread.
♪♪
And a light bulb.
♪♪
Anything else?
Martha: I know he's in there.
-So? -Why are you hiding him?
I'm not.
He was dropped off by taxi,
he walked through the front door,
and he's now sitting in the lounge with a rum and Coke.
-Well, let me in, then. -So you can grill him,
like he's one of Humphrey's suspects?
Absolutely not.
Fine.
But if he murders you, don't come crying to me.
I won't.
♪♪
Humphrey: I just think it's the weirdest job I've ever worked on.
A murder victim killed
while playing the part of a murder victim.
And despite the fact he was stabbed in the back
forcefully enough to puncture a lung,
there was no blood.
Hmm?
There was no blood. Not even a trace.
And the worst thing is, there's so much media interest,
I've got the Chief Superintendent
constantly on my back.
Oh, um, Esther, she's looking for a job for her daughter.
I said to get her to give you a call.
Martha?
-Yes, that's fine. -Okay.
[ Gasps ] There's a car!
Right on cue.
-That was great. -I'm glad you enjoyed it.
Oliver: Bye now.
I can see you.
[ Sighs ]
Martha: Oh, hello.
-So, how did it go? -Anne: It was fine.
He was perfectly polite,
well-mannered, cleared his plate,
and didn't overstay his welcome.
So are you gonna see him again?
-Anne: No. I got the ick. -Ick?
You've got to learn all the terminology, darling.
"“Ick"” means you've gone off someone.
He slurped his soup.
-That's it? -Anne: Oh, that's enough.
Still, there's plenty more fish in the sea.
Or as your nan says, every pot has a lid.
After all, look at you two.
♪♪
♪♪
Morning, sir. We got news on Paul Yellen.
-Good. -Except he's not Paul Yellen.
His real name is Aidan Scarcroft.
He was Sarah Scarcroft's son,
which is why she left him her house in her will.
He changed his name by deed poll before moving to Shipton Abbott,
which explains the new passport,
log book, and credit card we found at his house.
Margo's running a check on his real name now.
There's something else that's a bit weird, sir.
We spoke to the steam train operator
about the debris on the track that slowed the train down.
Now, they said there were no reports of debris
in any of the tunnels.
Then why would they say there was?
♪♪
-Vivienne: There's your tea. -Thank you.
Henry: Oh, well that tunnel is 150 years old.
So, you know, brickwork falls down on the track sometimes.
Ah, thank you, love.
We heard of debris falling just last week.
Thought it best to be careful.
-Yes. -Why do you ask?
Well, if the train was specifically told to slow down,
that might be significant.
Someone wanting to get on board while it was moving, perhaps.
Would you see someone if they had?
I doubt it, you know.
We're quite a ways up front,
so we wouldn't really see what's going on in the back carriages.
No, no.
It was a bit of a long shot, um,
but always worth asking the question.
Yeah, sorry I'm not much help.
Ah, she's a beauty, isn't she?
Oh, gosh, yes, yes.
You like your trains, then?
Love them, particularly steam trains.
Yeah, I think it started when I watched
"The Railway Children" for the first time.
Even asked my mum if I could change my name to Peter.
Well, um, whenever you like, just ask and I'll take you out.
-Gosh, would you? -Mm.
Maybe I could bring my fiancée?
We're doing date nights.
Oh, it would be a pleasure.
Well, that is amazing. Thank you. Thank you.
-Thank you. -Man: Cheers, then.
Another dead end.
-Yes, but not a wasted journey. -Oh?
He's gonna let me ride in his engine for date night.
Martha's gonna love it.
I'm sure she will, sir.
[ Car engine starts ]
♪♪
♪♪
Esther: Okay. Thanks, Margo.
So, Aidan Scarcroft,
AKA Paul Yellen, was released from prison two years ago.
He served a 12-year sentence.
-Really? For what? -Manslaughter.
He was driving three times over the limit
and ploughed into a group of people waiting at a bus stop.
An elderly woman died. Nine others were injured,
some quite badly.
Pull up the file, would you?
And cross-check the names of the people involved to see
if we can find any links to the people on our train?
Exactly.
Charlie: I understand that,
but Inspector Goodman is an experienced murder detective.
He's been making...
No, sir, he's not at the hub.
He's in one of our smaller outposts.
What would you suggest?
[ Mobile ringing ]
[ Sighs ]
Ma'am?
Command have instructed me
to move your investigation into the hub.
Well, no, you can't. Um, we're making progress.
Charlie: This is not a subject for discussion, Inspector.
You'll report to the hub at 9:00 a.m. tomorrow morning
with whatever you have.
We'll set up a murder room here.
-Right. But -- -Charlie: I'm sorry.
This isn't a reflection on you...
or your team.
Isn't it?
9:00 a.m. tomorrow morning.
Okay?
Mm-hmm.
♪♪
♪♪
♪♪
♪♪
I think I've got it.
The collision at the bus stop --
it happened in High Broughton, a village just outside Exeter.
One of the worst injured was an 11-year-old boy,
Christopher Bishfield.
Bishfield.
There were pictures of Vivienne and Harry
with a young boy at the house.
Viv and Harry moved here from Exeter.
Mm-hmm.
So, Vivienne and Harry Bishfield would have been there
when Aidan Scarcroft turned up with George to join the Players.
Give me a call when you're done, love.
-Alright. I will. -Okay, love you.
Nice to meet you.
You see, Aidan Scarcroft was here to start a new life.
He didn't recognise the father of the boy he injured.
Why would he?
I doubt they ever met.
But even after 12 years,
they'd never forget the face of the man
who ruined their child's life.
Humphrey: And it was that evening that Polly Deakins
saw a man standing across the road from her house.
So he followed Paul Yellen home, to get revenge?
So, if Harry Bishfield is our man, how?
I knew there was a reason this bothered me.
Yes.
The fireman on the train said
he had a call about debris on the line,
yet when we talked to Harry,
he said he slowed the train as a precaution.
Then why would the fireman say they had a call?
Because that's what his engine driver told him.
Kelby, call the operators.
Ask them what the procedure is if there's debris on the line.
Sir.
Alright?
Humphrey: Harry knew that as they approached the last tunnel
before Shipton Abbott,
the murder mystery suspects
were in the third carriage being questioned.
To be clear, the deceased was seen alive and well
at the very moment the train entered the tunnel,
and that the supposed victim, Aidan Scarcroft,
would be in the buffet car alone.
So first, he told his fireman
there was a report of debris on the line ahead.
-Examine the line, mate. -Okay, mate.
Then what?
Okay, so, if they suspect debris on the line,
the engine driver slows the train
and the fireman moves to the footplate
at the side of the train to look at the track ahead.
If they're in a tunnel they would use a torch.
Yes!
Once Kieran was out of the cab,
Harry slowed the train and then climbed back across the engine.
He knew exactly how long they would be in the tunnel.
He quickly made his way to the buffet car.
[ Paul grunts ]
Once done, he had moments to get back to the engine
before they reached the end of the tunnel
and Kieran would notice him missing.
♪♪
Kieran: All clear.
That doesn't explain why there was no blood around the body.
No. No, it doesn't.
But it's enough to bring him in.
He was 11 years old,
standing at the bus stop with a friend's mum.
They were going into town to go crab fishing on the quay.
[ Chuckles ]
Scarcroft was drunk. Off his head.
Chris was leaning against the wall behind the bus stop...
...when the car ploughed through everyone and into that wall.
He didn't have a chance.
His legs were shattered.
He had five years of operations.
He was in constant pain.
[ Sniffles ]
Me and his mum watched him go through all that,
saw how tough it was on him.
That changed him.
[ Sniffles ]
He was never the same, not really.
[ Sniffles ]
That man, he stole my son's childhood.
A little boy who left the house that morning...
excited to be meeting his friends...
who never came home.
Never came home.
[ Sniffles ]
And how is he now?
He took his own life
six years ago.
That's why we moved here.
He'd just turned 19.
[ Sniffles ]
Your lot said it was suicide.
Just another troubled teenager not coping.
Mm.
But that man, he killed my son,
just as sure as if he'd died that morning...
...and killed him the moment he came out of the pub
and got behind that wheel.
[ Sniffles ]
So, yes,
I killed him.
But if you want me to be sorry for what I did,
I can't.
Humphrey: I'm not asking anything of you.
To be honest, I can't imagine the pain
and the torment you and your family have gone through.
♪♪
Okay, let's take a break there.
I'm sure you and your lawyer
will want to discuss what's been said here.
I just have one more question.
When you entered the buffet car
and you saw Mr. Scarcroft standing at the food table,
can you think of any reason we didn't find any blood there?
Was there something on the floor you disposed of,
or something else?
He wasn't standing.
Sorry?
When I went into the buffet car, he was laying down on the floor.
♪♪
♪♪
Why was he already on the floor?
He must have just got back into position for act three.
-How likely is that? -Not very.
We know the cause of death was the knife puncturing his lung,
and we know who stabbed him and why,
but something just doesn't add up.
We've got the full post-mortem back.
Nothing surprising there.
Though there's a marker in the toxicology report.
I haven't had a chance to look it up yet.
Look up what?
There were traces of a substance called curare in his blood.
Curare? I know that from somewhere.
Let me see.
At least I think that's right.
♪♪
-Curare! -Eh.
Humphrey: Of course.
There are only two possible reasons
for there to be so little blood
found at the scene of a stabbing so serious.
If the body was killed elsewhere and moved.
Humphrey: And the second one?
If the victim is already dead.
Dead bodies don't bleed.
Yes.
This plaster found on his hand...
...did it happen on the train?
Yeah,
when we were doing fittings.
Vivienne?
♪♪
Vivienne: See how you get on tonight.
I can always let it out a bit more.
Ow!
Vivienne: Sorry.
Alright, everyone, final dress rehearsal.
Next time we do it will be in front of paying guests...
There was a pin left in the cuff.
I must have forgotten to unpin it.
I've got some plasters.
I'll put some antiseptic on,
stop it getting infected.
♪♪
Why?
Because curare only works
when it's injected directly under the skin.
So I tend to do running repairs.
Who better than a biology teacher to know that curare
is made by boiling the bark of certain plants?
Amazonian tribes used it to poison darts
and arrows when hunting.
It paralyses muscle tissue, stops the breathing.
I think Aidan Scarcroft was already dead
when Harry stabbed him.
I knew Harry was planning on killing him.
I didn't know how or when,
but I knew he'd do it.
You found him outside Aidan's house, didn't you?
What are you doing out here? You're gonna be seen.
What are you doing here? Leave me!
Vivienne: Just come home with me now
and let's just forget all about this.
No! You know I have to do this. Please.
Just come home.
He wanted to do it that night,
but there's the thing, you see.
I knew I couldn't stop him,
but I knew he'd get caught.
He's a simple man.
You killed Aidan Scarcroft
to stop your husband from doing so?
I couldn't think of any other way.
He's had so much pain in his life.
He's a good man.
I couldn't see him in prison.
How could I?
And yet you'd risk the same thing for yourself?
I don't have a life.
Not anymore.
My life ended the day I buried my baby boy.
Everyone tells you, "“Just take it a day at a time."”
So that's what I do --
go through the motions.
You have to switch off, you see, because every morning
when you wake up, the pain just comes back.
Never free of it.
So do what you want with me.
I won't feel anything.
♪♪
♪♪
So now we know why he was on the floor when Harry found him.
The poison did its work
while the rest of us were in the next carriage.
I think he was dead before he hit the floor.
[ Grunting ]
♪♪
Humphrey: Harry found Paul Yellen face down on the floor
and naturally assumed he'd simply taken up
his position as murder victim,
making it easy to plunge the knife into the back
of the man he held responsible for the death of his son.
Then he returned to the engine
before his fireman noticed he had gone.
And as he was already dead, his heart had stopped pumping.
He didn't bleed out. -Exactly.
Paul Yellen was a man who was murdered twice.
♪♪
♪♪
♪♪
[ Sobbing ]
♪ When this voice retires from talking ♪
♪ When these ears are tired of ringing ♪
♪ When my feet get bored of travelling ♪
♪ And it looks like it's all unravelling ♪
♪ When this heart's too old for dreaming ♪
♪ That's when I hear the angels sing your lullaby ♪
♪ 'Cause when I'm seeing double ♪
♪ It's your lullaby love that's keeping me from trouble ♪
♪ It's your lullaby love that's keeping me level ♪
♪ It's your lullaby love that keeps me awake ♪
Sometimes, I really hate my job.
I know.
What will happen to her?
Well, that depends on the CPS
and who they deem responsible for Aidan Scarcroft's death.
[ Sighs ]
I'll tell the Chief Super the good news.
♪♪
♪♪
Oh, so I spoke to Esther's daughter.
Oh, Zoe.
She'll start next week. See how we get on.
Great.
Wait, what are we doing here?
Surprise.
♪♪
So our mystery date night is looking at a train?
A steam train.
And minus the murder this time, hopefully.
Quick tour and a few photos, then I'll buy you dinner.
Promise.
And look, isn't it amazing?
Yes, it is.
Thank you for letting us do this,
especially given the circumstances.
-No worries. -Yes.
Probably know your way around by now.
Yeah. Kieran will tell you all about the boiler.
Great.
♪♪
I was telling the Inspector it was my granddad who me started.
♪♪
Now I'll be starting my driver's exam next month.
♪ Paradise... ♪
Is it supposed to be moving?
Sorry.
Humphrey!
Um...
Martha: Humphrey!
♪M
Um, call the restaurant!
Tell them we might be a bit late!
[ Laughs ]
♪♪
♪♪
♪♪
♪♪
♪♪
Can't find what you're looking for?
Get subtitles in any language from opensubtitles.com, and translate them here.